package CPAN::Smoke::Mistake;

use strict;
use vars qw($VERSION @ISA);

$VERSION = 0.01;

use CLASS;
require Class::Accessor;
@ISA = qw(Class::Accessor);

CLASS->mk_accessors(qw(by is_fatal name fix more_info));

use Data::Denter;
$Data::Denter::HashMode = 1;

my %Mistakes = Undent(join '', <DATA>);


=head1 NAME

CPAN::Smoke::Mistake - Objects representing fuck-ups in CPAN modules

=head1 SYNOPSIS

  use CPAN::Smoke::Mistake;

  my $mistake = CPAN::Smoke::Mistake->new($mistake_name, $more_info);

  my $by    = $mistake->by;
  my $fatal = $mistake->is_fatal;
  my $name  = $mistake->name;
  my $fix   = $mistake->fix;
  my $info  = $mistake->more_info

=head1 DESCRIPTION

An object representing a mistake made when smoking a CPAN module.  It
could be a mistake by the author, by CPAN or by CPAN::Smoke itself.

Mistakes are read in from a config file.

=head2 Constructor

  my $mistake = CPAN::Smoke::Mistake->new($name, $more_info);

Generates a new mistake.  $name must be in the list of known mistakes.
$more_info is further information about the mistake 

=cut

sub new {
    my($class, $name, $more_info) = @_;

    my $mistake = $Mistakes{$name};
    return unless defined $mistake;

    $mistake->{name} = $name;
    $mistake->{more_info} = $more_info if defined $more_info;
    my $self = $class->SUPER::new($mistake);

    return $self;
}


__DATA__
File Not Found => %
    by => CPAN
    is_fatal => 1
    description => Couldn't find your module on CPAN
    fix => Contact modules@perl.org

Naughty Archive => %
    by => Author
    is_fatal => 1
    descripton => Your archive is trying to do NAUGHTY THINGS!  See Archive::Any for an exact definition of naughty.
    fix => Use make dist instead of rolling your own archvies.

Impolite Archive => %
    by => Author
    is_fatal => 0
    description => Your archive didn't make it's own directory to unpack into.
    fix => Use make dist instead of rolling your own archives.

Bad Archive => %
    by => Author
    is_fatal => 1
    description => Your archive appears to be corrupt.
    fix => Use make dist instead of rolling your own archives.

Fetch Dir Doesn't Exist => %
    by => CPANTS
    is_fatal => 1
    description => Can't find the directory I'm supposed to download modules into
    fix => Make a directory, dumbass

Can't Fetch Module => %
    by => CPANTS
    is_fatal => 1
    description => Can't download the module from CPAN
    fix => Contact modules@perl.org maybe?

Couldn't Run Makefile.PL => %
    by => CPANTS
    is_fatal => 1
    description => There's a Makefile.PL, but I can't run it at all.

No Makefile.PL => %
    by => Author
    is_fatal => 1
    description => Your module has no Makefile.PL.
    fix => Write a Makefile.PL.  Read perlmodtut.
